import { WebSocketData, WebSocketClientConnectionProtocol, WebSocketClientConnection } from '@mswjs/interceptors/WebSocket';

type WebSocketBroadcastChannelMessage = {
    type: 'connection:open';
    payload: {
        clientId: string;
        url: string;
    };
} | {
    type: 'extraneous:send';
    payload: {
        clientId: string;
        data: WebSocketData;
    };
} | {
    type: 'extraneous:close';
    payload: {
        clientId: string;
        code?: number;
        reason?: string;
    };
};
declare const kAddByClientId: unique symbol;
/**
 * A manager responsible for accumulating WebSocket client
 * connections across different browser runtimes.
 */
declare class WebSocketClientManager {
    private channel;
    /**
     * All active WebSocket client connections.
     */
    clients: Set<WebSocketClientConnectionProtocol>;
    constructor(channel: BroadcastChannel);
    /**
     * Adds the given `WebSocket` client connection to the set
     * of all connections. The given connection is always the complete
     * connection object because `addConnection()` is called only
     * for the opened connections in the same runtime.
     */
    addConnection(client: WebSocketClientConnection): void;
    /**
     * Adds a client connection wrapper to operate with
     * WebSocket client connections in other runtimes.
     */
    private onRemoteConnection;
}
/**
 * A wrapper class to operate with WebSocket client connections
 * from other runtimes. This class maintains 1-1 public API
 * compatibility to the `WebSocketClientConnection` but relies
 * on the given `BroadcastChannel` to communicate instructions
 * with the client connections from other runtimes.
 */
declare class WebSocketRemoteClientConnection implements WebSocketClientConnectionProtocol {
    readonly id: string;
    readonly url: URL;
    private channel;
    constructor(id: string, url: URL, channel: BroadcastChannel);
    send(data: WebSocketData): void;
    close(code?: number | undefined, reason?: string | undefined): void;
}

export { type WebSocketBroadcastChannelMessage, WebSocketClientManager, WebSocketRemoteClientConnection, kAddByClientId };
