"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var WebSocketClientManager_exports = {};
__export(WebSocketClientManager_exports, {
  WebSocketClientManager: () => WebSocketClientManager,
  WebSocketRemoteClientConnection: () => WebSocketRemoteClientConnection,
  kAddByClientId: () => kAddByClientId
});
module.exports = __toCommonJS(WebSocketClientManager_exports);
const kAddByClientId = Symbol("kAddByClientId");
class WebSocketClientManager {
  constructor(channel) {
    this.channel = channel;
    this.clients = /* @__PURE__ */ new Set();
    this.channel.addEventListener("message", (message) => {
      const { type, payload } = message.data;
      switch (type) {
        case "connection:open": {
          this.onRemoteConnection(payload.clientId, new URL(payload.url));
          break;
        }
      }
    });
  }
  /**
   * All active WebSocket client connections.
   */
  clients;
  /**
   * Adds the given `WebSocket` client connection to the set
   * of all connections. The given connection is always the complete
   * connection object because `addConnection()` is called only
   * for the opened connections in the same runtime.
   */
  addConnection(client) {
    this.clients.add(client);
    this.channel.postMessage({
      type: "connection:open",
      payload: {
        clientId: client.id,
        url: client.url.toString()
      }
    });
    const handleExtraneousMessage = (message) => {
      const { type, payload } = message.data;
      if (typeof payload === "object" && "clientId" in payload && payload.clientId !== client.id) {
        return;
      }
      switch (type) {
        case "extraneous:send": {
          client.send(payload.data);
          break;
        }
        case "extraneous:close": {
          client.close(payload.code, payload.reason);
          break;
        }
      }
    };
    const abortController = new AbortController();
    this.channel.addEventListener("message", handleExtraneousMessage, {
      signal: abortController.signal
    });
    client.addEventListener("close", () => abortController.abort(), {
      once: true
    });
  }
  /**
   * Adds a client connection wrapper to operate with
   * WebSocket client connections in other runtimes.
   */
  onRemoteConnection(id, url) {
    this.clients.add(
      // Create a connection-compatible instance that can
      // operate with this client from a different runtime
      // using the BroadcastChannel messages.
      new WebSocketRemoteClientConnection(id, url, this.channel)
    );
  }
}
class WebSocketRemoteClientConnection {
  constructor(id, url, channel) {
    this.id = id;
    this.url = url;
    this.channel = channel;
  }
  send(data) {
    this.channel.postMessage({
      type: "extraneous:send",
      payload: {
        clientId: this.id,
        data
      }
    });
  }
  close(code, reason) {
    this.channel.postMessage({
      type: "extraneous:close",
      payload: {
        clientId: this.id,
        code,
        reason
      }
    });
  }
}
//# sourceMappingURL=WebSocketClientManager.js.map